@@ -344,8 +344,15 @@ class TestPythonMatlabFormat(object):
 
     @raises(NotImplementedError)
     def test_str_ascii_encoded_utf8(self):
-        data = random_str_some_unicode(random.randint(1, \
-            max_string_length)).encode('UTF-8')
+        ltrs = string.ascii_letters + string.digits
+        data = 'a'
+        if sys.hexversion < 0x03000000:
+            data = unicode(data)
+            ltrs = unicode(ltrs)
+        while all([(c in ltrs) for c in data]):
+            data = random_str_some_unicode(random.randint(1, \
+                max_string_length))
+        data = data.encode('utf-8')
         out = self.write_readback(data, random_name(),
                                   self.options)
         self.assert_equal(out, data)
@@ -517,7 +524,7 @@ class TestPythonMatlabFormat(object):
         if sys.hexversion >= 0x03000000:
             ch = '\x00'
         else:
-            ch = u'\x00'
+            ch = unicode('\x00')
         key = ch.join([random_str_ascii(max_dict_key_length)
                       for i in range(2)])
         data[key] = random_int()
@@ -531,7 +538,7 @@ class TestPythonMatlabFormat(object):
         if sys.hexversion >= 0x03000000:
             ch = '/'
         else:
-            ch = u'/'
+            ch = unicode('/')
         key = ch.join([random_str_ascii(max_dict_key_length)
                       for i in range(2)])
         data[key] = random_int()
@@ -551,8 +558,15 @@ class TestPythonFormat(TestPythonMatlabFormat):
 
     # Won't throw an exception unlike the parent.
     def test_str_ascii_encoded_utf8(self):
-        data = random_str_some_unicode(random.randint(1,
-            max_string_length)).encode('UTF-8')
+        ltrs = string.ascii_letters + string.digits
+        data = 'a'
+        if sys.hexversion < 0x03000000:
+            data = unicode(data)
+            ltrs = unicode(ltrs)
+        while all([(c in ltrs) for c in data]):
+            data = random_str_some_unicode(random.randint(1, \
+                max_string_length))
+        data = data.encode('utf-8')
         out = self.write_readback(data, random_name(),
                                   self.options)
         self.assert_equal(out, data)
@@ -580,8 +594,15 @@ class TestNoneFormat(TestPythonMatlabFormat):
 
     # Won't throw an exception unlike the parent.
     def test_str_ascii_encoded_utf8(self):
-        data = random_str_some_unicode(random.randint(1,
-            max_string_length)).encode('UTF-8')
+        ltrs = string.ascii_letters + string.digits
+        data = 'a'
+        if sys.hexversion < 0x03000000:
+            data = unicode(data)
+            ltrs = unicode(ltrs)
+        while all([(c in ltrs) for c in data]):
+            data = random_str_some_unicode(random.randint(1, \
+                max_string_length))
+        data = data.encode('utf-8')
         out = self.write_readback(data, random_name(),
                                   self.options)
         self.assert_equal(out, data)
